Files
codex/prs/bolinfest/PR-1891.md
2025-09-02 15:17:45 -07:00

1.9 KiB

PR #1891: fix: support $CODEX_HOME/AGENTS.md instead of $CODEX_HOME/instructions.md

Description

The docs and code do not match. It turns out the docs are "right" in they are what we have been meaning to support, so this PR updates the code:

ae88b69b09/README.md (L298-L302)

Support for instructions.md is a holdover from the TypeScript CLI, so we are just going to drop support for it altogether rather than maintain it in perpetuity.

Full Diff

diff --git a/codex-rs/core/src/config.rs b/codex-rs/core/src/config.rs
index 0b53df5ab7..f48cc9340b 100644
--- a/codex-rs/core/src/config.rs
+++ b/codex-rs/core/src/config.rs
@@ -70,7 +70,7 @@ pub struct Config {
     /// who have opted into Zero Data Retention (ZDR).
     pub disable_response_storage: bool,
 
     /// User-provided instructions from instructions.md.
     pub user_instructions: Option<String>,
 
     /// Base instructions override.
@@ -575,7 +575,7 @@ impl Config {
             None => return None,
         };
 
-        p.push("instructions.md");
+        p.push("AGENTS.md");
         std::fs::read_to_string(&p).ok().and_then(|s| {
             let s = s.trim();
             if s.is_empty() {

Review Comments

codex-rs/core/src/config.rs

@@ -575,7 +575,7 @@ impl Config {
             None => return None,
         };
 
-        p.push("instructions.md");
+        p.push("AGENTS.md");
@@ -70,7 +70,7 @@ pub struct Config {
     pub disable_response_storage: bool,
 
-    /// User-provided instructions from instructions.md.
+    /// User-provided instructions from AGENTS.md.
     pub user_instructions: Option<String>,
 

I thought about it, but I don't think we want to honor instructions.md in perpetuity.